==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property exacts Values sent must match the specified values exactly.
 */
public data class
VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs(
    public val exacts: Output<List<String>>,
) :
    ConvertibleToJava<com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs> {
    override fun toJava():
        com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs =
        com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs.builder()
            .exacts(exacts.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs].
 */
@PulumiTagMarker
public class
VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgsBuilder
internal constructor() {
    private var exacts: Output<List<String>>? = null

    /**
     * @param value Values sent must match the specified values exactly.
     */
    @JvmName("obwuerjcumfnwujv")
    public suspend fun exacts(`value`: Output<List<String>>) {
        this.exacts = value
    }

    @JvmName("hcrodbqbkoebumyr")
    public suspend fun exacts(vararg values: Output<String>) {
        this.exacts = Output.all(values.asList())
    }

    /**
     * @param values Values sent must match the specified values exactly.
     */
    @JvmName("gxqwhssxccuhnpsb")
    public suspend fun exacts(values: List<Output<String>>) {
        this.exacts = Output.all(values)
    }

    /**
     * @param value Values sent must match the specified values exactly.
     */
    @JvmName("llguthlgqotovard")
    public suspend fun exacts(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exacts = mapped
    }

    /**
     * @param values Values sent must match the specified values exactly.
     */
    @JvmName("qcvvffqcnknllfxi")
    public suspend fun exacts(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exacts = mapped
    }

    internal fun build():
        VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs =
        VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs(
            exacts = exacts ?: throw PulumiNullFieldException("exacts"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property exacts Values sent must match the specified values exactly.
 */
public data class
VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs(
    public val exacts: Output<List<String>>,
) :
    ConvertibleToJava<com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs =
        com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs.builder()
            .exacts(exacts.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs].
 */
@PulumiTagMarker
public class
VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgsBuilder
internal constructor() {
    private var exacts: Output<List<String>>? = null

    /**
     * @param value Values sent must match the specified values exactly.
     */
    @JvmName("plgkksfxdybfccht")
    public suspend fun exacts(`value`: Output<List<String>>) {
        this.exacts = value
    }

    @JvmName("esysrathgkaskeav")
    public suspend fun exacts(vararg values: Output<String>) {
        this.exacts = Output.all(values.asList())
    }

    /**
     * @param values Values sent must match the specified values exactly.
     */
    @JvmName("fjiaohpscplfplcj")
    public suspend fun exacts(values: List<Output<String>>) {
        this.exacts = Output.all(values)
    }

    /**
     * @param value Values sent must match the specified values exactly.
     */
    @JvmName("kxdtwqccqulrhlpu")
    public suspend fun exacts(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exacts = mapped
    }

    /**
     * @param values Values sent must match the specified values exactly.
     */
    @JvmName("lgqfsytuytvnfgfl")
    public suspend fun exacts(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exacts = mapped
    }

    internal fun build(): VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs =
        VirtualGatewaySpecBackendDefaultsClientPolicyTlsValidationSubjectAlternativeNamesMatchArgs(
            exacts = exacts ?: throw PulumiNullFieldException("exacts"),
        )
}
